@@ -1,67 +1,69 @@
 var languageNames = {
 "en-US": "Englisch (USA)",
+"sq": "Albanisch",
 "am": "Amharisch",
 "ar": "Arabisch",
 "ast": "Asturisch",
-"bg": "Bulgarisch",
 "bn": "Bengalisch",
 "bn-IN": "Bengalisch (Indien)",
-"bo": "Tibetisch",
 "bs": "Bosnisch",
+"bg": "Bulgarisch",
 "ca": "Katalanisch",
-"ca-valencia": "Valencianisches Katalanisch",
+"ca-valencia": "Katalanisch (Valencia)",
+"zh-CN": "Chinesisch (vereinfacht)",
+"zh-TW": "Chinesisch (traditionell)",
+"hr": "Kroatisch",
 "cs": "Tschechisch",
 "da": "Dänisch",
-"de": "Deutsch",
+"nl": "Niederländisch",
 "dz": "Dzongkha",
-"el": "Griechisch",
 "en-GB": "Englisch (UK)",
 "en-ZA": "Englisch (SA)",
 "eo": "Esperanto",
-"es": "Spanisch",
 "et": "Estnisch",
 "eu": "Baskisch",
 "fi": "Finnisch",
 "fr": "Französisch",
 "gl": "Galizisch",
+"ka": "Georgisch",
+"de": "Deutsch",
+"el": "Griechisch",
 "gu": "Gujaratisch",
 "he": "Hebräisch",
 "hi": "Hindi",
-"hr": "Kroatisch",
 "hu": "Ungarisch",
 "id": "Indonesisch",
 "is": "Isländisch",
 "it": "Italienisch",
 "ja": "Japanisch",
-"ka": "Georgisch",
 "km": "Khmer",
 "ko": "Koreanisch",
 "lo": "Laotisch",
-"lt": "Litauisch",
 "lv": "Lettisch",
+"lt": "Litauisch",
 "mk": "Mazedonisch",
-"nb": "Norwegisches Bokmål",
 "ne": "Nepalesisch",
-"nl": "Niederländisch",
 "nn": "Norwegisches Nynorsk",
+"nb": "Norwegisches Bokmål",
 "om": "Oromo",
 "pl": "Polnisch",
 "pt": "Portugiesisch",
-"pt-BR": "Brasilianisches Portugiesisch",
+"pt-BR": "Portugiesisch (Brasilien)",
 "ro": "Rumänisch",
 "ru": "Russisch",
-"si": "Singhalesisch",
 "sid": "Sidama",
+"si": "Singhalesisch",
 "sk": "Slowakisch",
 "sl": "Slowenisch",
-"sq": "Albanisch",
+"dsb": "Sorbian (Lower)",
+"hsb": "Sorbian (Upper)",
+"es": "Spanisch",
 "sv": "Schwedisch",
-"ta": "Tamilisch",
 "tg": "Tadschikisch",
+"ta": "Tamilisch",
+"bo": "Tibetisch",
 "tr": "Türkisch",
 "ug": "Uigurisch",
 "uk": "Ukrainisch",
 "vi": "Vietnamesisch",
-"zh-CN": "Chinesisch (vereinfacht)",
-"zh-TW": "Chinesisch (traditionell)",
 };
